@@ -22,10 +22,12 @@
 
 
 #include "flagdatainformation.h"
-#include "structviewpreferences.h"
 #include <QVarLengthArray>
+#include <KLocalizedString>
 
-FlagDataInformation::FlagDataInformation(QString name, PrimitiveDataInformation* type,
+
+
+FlagDataInformation::FlagDataInformation(const QString& name, PrimitiveDataInformation* type,
         EnumDefinition::Ptr enumDef, DataInformation* parent)
     : EnumDataInformation(name, type, enumDef, parent)
 {
@@ -47,6 +49,7 @@ static void removeFromArray(QVarLengthArray<T, len>& array, int index) {
 
 QString FlagDataInformation::valueString() const
 {
+    Q_ASSERT(mWasAbleToRead);
     QMapIterator<AllPrimitiveTypes, QString> iter(mEnum->values());
     //I doubt more than 10 flags will be set very often -> only then do we need a malloc
     QVarLengthArray<FlagPair, 10> arr;
@@ -120,8 +123,3 @@ QString FlagDataInformation::typeName() const
 {
     return i18n("flags (%1)", mValue->typeName());
 }
-
-QString FlagDataInformation::getTypeString() const
-{
-    return i18nc("bit flags, i.e. 'R | W | X' with undelying type", "flags(%1)", mValue->typeName());
-}
