@@ -30,7 +30,7 @@ class UMLUniqueConstraint : public UMLEntityConstraint
 public:
 
     UMLUniqueConstraint(UMLObject *parent, const QString& name,
-                        Uml::IDType id = Uml::id_None );
+                        Uml::ID::Type id = Uml::ID::None );
     explicit UMLUniqueConstraint(UMLObject *parent);
     virtual ~UMLUniqueConstraint();
 
@@ -40,7 +40,7 @@ public:
 
     virtual UMLObject* clone() const;
 
-    QString toString(Uml::SignatureType sig = Uml::SignatureType::NoSig);
+    QString toString(Uml::SignatureType::Enum sig = Uml::SignatureType::NoSig);
 
     QString getFullyQualifiedName(const QString& separator = QString(),
                                   bool includeRoot = false) const;
