@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -31,14 +31,14 @@
  * @param activityType      The type of activity.
  * @param id                The ID to assign (-1 will prompt a new ID.)
  */
-ActivityWidget::ActivityWidget(UMLScene * scene, ActivityType activityType, Uml::IDType id)
+ActivityWidget::ActivityWidget(UMLScene * scene, ActivityType activityType, Uml::ID::Type id)
   : UMLWidget(scene, WidgetBase::wt_Activity, id),
     m_activityType(activityType)
 {
 }
 
 /**
- *  destructor
+ *  Destructor.
  */
 ActivityWidget::~ActivityWidget()
 {
