@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -182,7 +182,7 @@ bool AssociationLine::insertPoint(int pointIndex, const UMLScenePoint &point)
         UMLScenePoint ep = first->line().p2();
         first->setLine( sp.x(), sp.y(), point.x(), point.y() );
         QGraphicsLineItem* line = new QGraphicsLineItem;
-        canvas()->addItem(line);
+        umlScene()->addItem(line);
         line->setZValue( -2 );
         line->setLine( point.x(), point.y(), ep.x(), ep.y() );
         line->setPen( pen() );
@@ -198,7 +198,7 @@ bool AssociationLine::insertPoint(int pointIndex, const UMLScenePoint &point)
         UMLScenePoint ep = before->line().p2();
         before->setLine( sp.x(), sp.y(), point.x(), point.y() );
         QGraphicsLineItem* line = new QGraphicsLineItem;
-        canvas()->addItem(line);
+        umlScene()->addItem(line);
         line->setLine( point.x(), point.y(), ep.x(), ep.y() );
         line->setZValue( -2 );
         line->setPen( pen() );
@@ -213,7 +213,7 @@ bool AssociationLine::insertPoint(int pointIndex, const UMLScenePoint &point)
     UMLScenePoint ep = before->line().p2();
     before->setLine( sp.x(), sp.y(), point.x(), point.y() );
     QGraphicsLineItem* line = new QGraphicsLineItem;
-    canvas()->addItem(line);
+    umlScene()->addItem(line);
     line->setLine( point.x(), point.y(), ep.x(), ep.y() );
     line->setZValue( -2 );
     line->setPen( pen() );
@@ -324,8 +324,8 @@ void AssociationLine::cleanup()
     m_pSubsetSymbol = 0;
     m_bHeadCreated = m_bParallelLineCreated = m_bSubsetSymbolCreated = false;
     if (m_associationWidget) {
-        disconnect(m_associationWidget->umlScene(), SIGNAL(sigLineColorChanged(Uml::IDType)), this, SLOT(slotLineColorChanged(Uml::IDType)));
-        disconnect(m_associationWidget->umlScene(), SIGNAL(sigLineWidthChanged(Uml::IDType)), this, SLOT(slotLineWidthChanged(Uml::IDType)));
+        disconnect(m_associationWidget->umlScene(), SIGNAL(sigLineColorChanged(Uml::ID::Type)), this, SLOT(slotLineColorChanged(Uml::ID::Type)));
+        disconnect(m_associationWidget->umlScene(), SIGNAL(sigLineWidthChanged(Uml::ID::Type)), this, SLOT(slotLineWidthChanged(Uml::ID::Type)));
         m_associationWidget = 0;
     }
 }
@@ -340,7 +340,7 @@ void AssociationLine::cleanup()
  */
 int AssociationLine::closestPointIndex(const UMLScenePoint &position)
 {
-    UMLSceneItemList list = canvas()->collisions( position );
+    UMLSceneItemList list = umlScene()->collisions( position );
     int index = -1;
 
     UMLSceneItemList::iterator end(list.end());
@@ -388,7 +388,7 @@ bool AssociationLine::setEndPoints(const UMLScenePoint &start, const UMLScenePoi
     int count = m_LineList.count();
     if( count == 0 ) {
         QGraphicsLineItem* line = new QGraphicsLineItem;
-        canvas()->addItem(line);
+        umlScene()->addItem(line);
         line->setLine( start.x(), start.y(),end.x(),end.y() );
         line->setZValue( -2 );
         line->setPen( pen() );
@@ -498,7 +498,7 @@ void AssociationLine::saveToXMI(QDomDocument &qDoc, QDomElement &qElement)
  */
 QPen AssociationLine::pen()
 {
-    Uml::AssociationType type = getAssocType();
+    Uml::AssociationType::Enum type = getAssocType();
     if( type == Uml::AssociationType::Dependency || type == Uml::AssociationType::Realization || type == Uml::AssociationType::Anchor )
         return QPen( lineColor(), lineWidth(), Qt::DashLine );
     return QPen( lineColor(), lineWidth() );
@@ -625,8 +625,8 @@ void AssociationLine::setAssociation(AssociationWidget * association)
     if( getAssocType() == Uml::AssociationType::Coll_Message )
         setupParallelLine();
     if (m_associationWidget) {
-        connect(m_associationWidget->umlScene(), SIGNAL(sigLineColorChanged(Uml::IDType)), this, SLOT(slotLineColorChanged(Uml::IDType)));
-        connect(m_associationWidget->umlScene(), SIGNAL(sigLineWidthChanged(Uml::IDType)), this, SLOT(slotLineWidthChanged(Uml::IDType)));
+        connect(m_associationWidget->umlScene(), SIGNAL(sigLineColorChanged(Uml::ID::Type)), this, SLOT(slotLineColorChanged(Uml::ID::Type)));
+        connect(m_associationWidget->umlScene(), SIGNAL(sigLineWidthChanged(Uml::ID::Type)), this, SLOT(slotLineWidthChanged(Uml::ID::Type)));
     }
     else {
         uWarning() << "scene is null. Can not connect SIGNAL/SLOT.";
@@ -641,7 +641,7 @@ void AssociationLine::setAssociation(AssociationWidget * association)
  * This class doesn't hold this information but is a wrapper
  * method to stop calls to undefined variable like m_associationWidget.
  */
-Uml::AssociationType AssociationLine::getAssocType() const 
+Uml::AssociationType::Enum AssociationLine::getAssocType() const
 {
     if( m_associationWidget )
         return m_associationWidget->associationType();
@@ -651,7 +651,7 @@ Uml::AssociationType AssociationLine::getAssocType() const
 /**
  * Sets the Association type.
  */
-void AssociationLine::setAssocType(Uml::AssociationType type)
+void AssociationLine::setAssocType(Uml::AssociationType::Enum type)
 {
     QList<QGraphicsLineItem*>::Iterator it = m_LineList.begin();
     QList<QGraphicsLineItem*>::Iterator end = m_LineList.end();
@@ -695,7 +695,7 @@ AssociationLine & AssociationLine::operator=(const AssociationLine & rhs)
 {
     if( this == &rhs )
         return *this;
-    //clear out the old canvas objects
+    //clear out the old scene objects
     this->cleanup();
 
     int count = rhs.m_LineList.count();
@@ -746,11 +746,11 @@ void AssociationLine::activate()
     int count = m_LineList.count();
     if (count == 0)
         return;
-    if (canvas() == NULL)
+    if (umlScene() == NULL)
         return;
     for (int i = 0; i < count ; i++) {
         QGraphicsLineItem *line = m_LineList.at(i);
-        canvas()->addItem(line);
+        umlScene()->addItem(line);
         line->setPen( pen() );
     }
 }
@@ -785,7 +785,7 @@ void AssociationLine::update()
  *
  * @param viewID The id of the object behind the widget.
  */
-void AssociationLine::slotLineColorChanged(Uml::IDType viewID)
+void AssociationLine::slotLineColorChanged(Uml::ID::Type viewID)
 {
     if(m_associationWidget->umlScene()->ID() != viewID) {
         return;
@@ -798,7 +798,7 @@ void AssociationLine::slotLineColorChanged(Uml::IDType viewID)
  *
  * @param viewID The id of the object behind the widget.
  */
-void AssociationLine::slotLineWidthChanged(Uml::IDType viewID)
+void AssociationLine::slotLineWidthChanged(Uml::ID::Type viewID)
 {
     if(m_associationWidget->umlScene()->ID() != viewID) {
         return;
@@ -807,13 +807,13 @@ void AssociationLine::slotLineWidthChanged(Uml::IDType viewID)
 }
 
 /**
- * Returns the canvas being used.
+ * Returns the scene being used.
  * Will return zero if the Association hasn't been set.
  *
  * This class doesn't hold this information but is a wrapper
  * method to stop calls to undefined variable like m_associationWidget.
  */
-UMLScene* AssociationLine::canvas()
+UMLScene* AssociationLine::umlScene()
 {
     if( !m_associationWidget )
         return 0;
@@ -821,7 +821,7 @@ UMLScene* AssociationLine::canvas()
 }
 
 /**
- * Moves the selected canvas widgets.
+ * Moves the selected scene widgets.
  */
 void AssociationLine::moveSelected(int pointIndex)
 {
@@ -883,7 +883,7 @@ void AssociationLine::calculateHead()
     UMLScenePoint farPoint;
     int halfLength = 10;
     double arrowAngle = 0.2618;   // 0.5 * atan(sqrt(3.0) / 3.0) = 0.2618
-    Uml::AssociationType at = getAssocType();
+    Uml::AssociationType::Enum at = getAssocType();
     bool diamond = (at == Uml::AssociationType::Aggregation || at == Uml::AssociationType::Composition);
     if (diamond || at == Uml::AssociationType::Containment) {
         farPoint = point(1);
@@ -981,7 +981,7 @@ void AssociationLine::createHeadLines()
     case Uml::AssociationType::Realization:
         growList(m_HeadList, 3);
         m_pClearPoly = new QGraphicsPolygonItem;
-        canvas()->addItem(m_pClearPoly);
+        umlScene()->addItem(m_pClearPoly);
         m_pClearPoly->setVisible( true );
         m_pClearPoly->setBrush( QBrush( Qt::white ) );
         m_pClearPoly->setZValue( -1 );
@@ -991,7 +991,7 @@ void AssociationLine::createHeadLines()
     case Uml::AssociationType::Aggregation:
         growList(m_HeadList, 4);
         m_pClearPoly = new QGraphicsPolygonItem;
-        canvas()->addItem(m_pClearPoly);
+        umlScene()->addItem(m_pClearPoly);
         m_pClearPoly->setVisible( true );
         if( getAssocType() == Uml::AssociationType::Aggregation )
             m_pClearPoly->setBrush( QBrush( Qt::white ) );
@@ -1004,7 +1004,7 @@ void AssociationLine::createHeadLines()
         growList(m_HeadList, 1);
         if (!m_pCircle) {
             m_pCircle = new Circle( 6 );
-            canvas()->addItem(m_pCircle);
+            umlScene()->addItem(m_pCircle);
             m_pCircle->show();
             m_pCircle->setPen( QPen( lineColor(), lineWidth() ) );
         }
@@ -1202,7 +1202,7 @@ void AssociationLine::createSubsetSymbol()
     switch( getAssocType() ) {
        case Uml::AssociationType::Child2Category:
            m_pSubsetSymbol = new SubsetSymbol;
-           canvas()->addItem(m_pSubsetSymbol);
+           umlScene()->addItem(m_pSubsetSymbol);
            m_pSubsetSymbol->setPen( QPen( lineColor(), lineWidth() ) );
            updateSubsetSymbol();
            m_pSubsetSymbol->show();
@@ -1267,7 +1267,7 @@ void AssociationLine::growList(LineList &list, int by)
     QPen pen( lineColor(), lineWidth() );
     for (int i = 0; i < by; i++) {
         QGraphicsLineItem* line = new QGraphicsLineItem;
-        canvas()->addItem(line);
+        umlScene()->addItem(line);
         line->setZValue( 0 );
         line->setPen( pen );
         line->setVisible( true );
