@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -51,21 +51,23 @@ public:
         Par
     };
 
-    explicit CombinedFragmentWidget( UMLScene * scene, CombinedFragmentType combinedfragmentType = Ref, Uml::IDType id = Uml::id_None );
+    explicit CombinedFragmentWidget(UMLScene * scene,
+                                    CombinedFragmentType combinedfragmentType = Ref,
+                                    Uml::ID::Type id = Uml::ID::None);
     virtual ~CombinedFragmentWidget();
 
     void draw(QPainter & p, int offsetX, int offsetY);
 
     CombinedFragmentType combinedFragmentType() const;
     CombinedFragmentType combinedFragmentType(const QString& combinedfragmentType) const;
-    void setCombinedFragmentType( CombinedFragmentType combinedfragmentType );
-    void setCombinedFragmentType( const QString& combinedfragmentType );
+    void setCombinedFragmentType(CombinedFragmentType combinedfragmentType);
+    void setCombinedFragmentType(const QString& combinedfragmentType);
 
     void askNameForWidgetType(UMLWidget* &targetWidget, const QString& dialogTitle,
                       const QString& dialogPrompt, const QString& defaultName);
 
-    void saveToXMI( QDomDocument & qDoc, QDomElement & qElement );
-    bool loadFromXMI( QDomElement & qElement );
+    void saveToXMI(QDomDocument & qDoc, QDomElement & qElement);
+    bool loadFromXMI(QDomElement & qElement);
 
 public slots:
     void slotMenuSelection(QAction* action);
