@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -41,9 +41,6 @@
 
 DEBUG_REGISTER_DISABLED(FloatingTextWidget)
 
-const UMLSceneValue FloatingTextWidget::restrictPositionMin = 0;
-const UMLSceneValue FloatingTextWidget::restrictPositionMax = 3000;
-
 /**
  * Constructs a FloatingTextWidget instance.
  *
@@ -52,7 +49,7 @@ const UMLSceneValue FloatingTextWidget::restrictPositionMax = 3000;
  * @param text The main text to display.
  * @param id The ID to assign (-1 will prompt a new ID.)
  */
-FloatingTextWidget::FloatingTextWidget(UMLScene * scene, Uml::TextRole role, const QString& text, Uml::IDType id)
+FloatingTextWidget::FloatingTextWidget(UMLScene * scene, Uml::TextRole::Enum role, const QString& text, Uml::ID::Type id)
   : UMLWidget(scene, WidgetBase::wt_Text, id, new FloatingTextWidgetController(this)),
     m_linkWidget(0),
     m_preText(QString()),
@@ -337,18 +334,18 @@ LinkWidget * FloatingTextWidget::link() const
 /**
  * Sets the role type of this FloatingTextWidget.
  *
- * @param role  The TextRole of this FloatingTextWidget.
+ * @param role  The TextRole::Enum of this FloatingTextWidget.
  */
-void FloatingTextWidget::setTextRole(Uml::TextRole role)
+void FloatingTextWidget::setTextRole(Uml::TextRole::Enum role)
 {
     m_textRole = role;
 }
 
 /**
  * Return the role of the text widget
- * @return The TextRole of this FloatingTextWidget.
+ * @return The TextRole::Enum of this FloatingTextWidget.
  */
-Uml::TextRole FloatingTextWidget::textRole() const
+Uml::TextRole::Enum FloatingTextWidget::textRole() const
 {
     return m_textRole;
 }
@@ -397,22 +394,22 @@ void FloatingTextWidget::changeName(const QString& newText)
         if (assoc) {
             switch (m_textRole) {
               case Uml::TextRole::MultiA:
-                assoc->setMultiplicity(QString(), Uml::A);
+                assoc->setMultiplicity(QString(), Uml::RoleType::A);
                 break;
               case Uml::TextRole::MultiB:
-                assoc->setMultiplicity(QString(), Uml::B);
+                assoc->setMultiplicity(QString(), Uml::RoleType::B);
                 break;
               case Uml::TextRole::RoleAName:
-                assoc->setRoleName(QString(), Uml::A);
+                assoc->setRoleName(QString(), Uml::RoleType::A);
                 break;
               case Uml::TextRole::RoleBName:
-                assoc->setRoleName(QString(), Uml::B);
+                assoc->setRoleName(QString(), Uml::RoleType::B);
                 break;
               case Uml::TextRole::ChangeA:
-                assoc->setChangeability(Uml::Changeability::Changeable, Uml::A);
+                assoc->setChangeability(Uml::Changeability::Changeable, Uml::RoleType::A);
                 break;
               case Uml::TextRole::ChangeB:
-                assoc->setChangeability(Uml::Changeability::Changeable, Uml::B);
+                assoc->setChangeability(Uml::Changeability::Changeable, Uml::RoleType::B);
                 break;
               default:
                 assoc->setName(QString());
@@ -486,7 +483,7 @@ bool FloatingTextWidget::loadFromXMI(QDomElement & qElement)
 
     QString role = qElement.attribute("role", "");
     if(!role.isEmpty())
-        m_textRole = Uml::TextRole::Value(role.toInt());
+        m_textRole = Uml::TextRole::fromInt(role.toInt());
 
     m_preText = qElement.attribute("pretext", "");
     m_postText = qElement.attribute("posttext", "");
