@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -47,18 +47,18 @@ DEBUG_REGISTER_DISABLED(MessageWidget)
  *                The default (-1) will prompt generation of a new ID.
  */
 MessageWidget::MessageWidget(UMLScene * scene, ObjectWidget* a, ObjectWidget* b,
-                             int y, Uml::Sequence_Message_Type sequenceMessageType,
-                             Uml::IDType id /* = Uml::id_None */)
+                             int y, Uml::SequenceMessage::Enum sequenceMessageType,
+                             Uml::ID::Type id /* = Uml::id_None */)
   : UMLWidget(scene, WidgetBase::wt_Message, id, new MessageWidgetController(this))
 {
     init();
-    m_pOw[Uml::A] = a;
-    m_pOw[Uml::B] = b;
+    m_pOw[Uml::RoleType::A] = a;
+    m_pOw[Uml::RoleType::B] = b;
     m_nY = y;
     m_sequenceMessageType = sequenceMessageType;
-    if (m_sequenceMessageType == Uml::sequence_message_creation) {
-        y -= m_pOw[Uml::B]->height() / 2;
-        m_pOw[Uml::B]->setY(y);
+    if (m_sequenceMessageType == Uml::SequenceMessage::Creation) {
+        y -= m_pOw[Uml::RoleType::B]->height() / 2;
+        m_pOw[Uml::RoleType::B]->setY(y);
     }
     updateResizability();
     calculateWidget();
@@ -73,11 +73,11 @@ MessageWidget::MessageWidget(UMLScene * scene, ObjectWidget* a, ObjectWidget* b,
  * Constructs a MessageWidget.
  *
  * @param scene              The parent to this class.
- * @param sequenceMessageType The Uml::Sequence_Message_Type of this message widget
+ * @param sequenceMessageType The Uml::SequenceMessage::Enum of this message widget
  * @param id                The ID to assign (-1 will prompt a new ID.)
  */
-MessageWidget::MessageWidget(UMLScene * scene, Uml::Sequence_Message_Type seqMsgType,
-                             Uml::IDType id)
+MessageWidget::MessageWidget(UMLScene * scene, Uml::SequenceMessage::Enum seqMsgType,
+                             Uml::ID::Type id)
   : UMLWidget(scene, WidgetBase::wt_Message, id, new MessageWidgetController(this))
 {
     init();
@@ -95,13 +95,13 @@ MessageWidget::MessageWidget(UMLScene * scene, Uml::Sequence_Message_Type seqMsg
  * @param id     The ID to assign (-1 will prompt a new ID.)
  */
 MessageWidget::MessageWidget(UMLScene * scene, ObjectWidget* a, int xclick, int yclick,
-                             Uml::Sequence_Message_Type sequenceMessageType,
-                             Uml::IDType id /*= Uml::id_None*/)
+                             Uml::SequenceMessage::Enum sequenceMessageType,
+                             Uml::ID::Type id /*= Uml::id_None*/)
   : UMLWidget(scene, WidgetBase::wt_Message, id, new MessageWidgetController(this))
 {
     init();
-    m_pOw[Uml::A] = a;
-    m_pOw[Uml::B] = a;
+    m_pOw[Uml::RoleType::A] = a;
+    m_pOw[Uml::RoleType::B] = a;
 
     m_sequenceMessageType = sequenceMessageType;
     m_nY = yclick;
@@ -127,7 +127,7 @@ void MessageWidget::init()
 {
     m_ignoreSnapToGrid = true;
     m_ignoreSnapComponentSizeToGrid = true;
-    m_pOw[Uml::A] = m_pOw[Uml::B] = NULL;
+    m_pOw[Uml::RoleType::A] = m_pOw[Uml::RoleType::B] = NULL;
     m_pFText = NULL;
     m_nY = 0;
     setVisible(true);
@@ -146,8 +146,8 @@ MessageWidget::~MessageWidget()
  */
 void MessageWidget::updateResizability()
 {
-    if (m_sequenceMessageType == Uml::sequence_message_synchronous ||
-        m_pOw[Uml::A] == m_pOw[Uml::B])
+    if (m_sequenceMessageType == Uml::SequenceMessage::Synchronous ||
+        m_pOw[Uml::RoleType::A] == m_pOw[Uml::RoleType::B])
         UMLWidget::m_resizable = true;
     else
         UMLWidget::m_resizable = false;
@@ -158,19 +158,19 @@ void MessageWidget::updateResizability()
  */
 void MessageWidget::draw(QPainter& p, int offsetX, int offsetY)
 {
-    if(!m_pOw[Uml::A] || !m_pOw[Uml::B]) {
+    if(!m_pOw[Uml::RoleType::A] || !m_pOw[Uml::RoleType::B]) {
         return;
     }
     setPenFromSettings(p);
-    if (m_sequenceMessageType == Uml::sequence_message_synchronous) {
+    if (m_sequenceMessageType == Uml::SequenceMessage::Synchronous) {
         drawSynchronous(p, offsetX, offsetY);
-    } else if (m_sequenceMessageType == Uml::sequence_message_asynchronous) {
+    } else if (m_sequenceMessageType == Uml::SequenceMessage::Asynchronous) {
         drawAsynchronous(p, offsetX, offsetY);
-    } else if (m_sequenceMessageType == Uml::sequence_message_creation) {
+    } else if (m_sequenceMessageType == Uml::SequenceMessage::Creation) {
         drawCreation(p, offsetX, offsetY);
-    } else if (m_sequenceMessageType == Uml::sequence_message_lost) {
+    } else if (m_sequenceMessageType == Uml::SequenceMessage::Lost) {
         drawLost(p, offsetX, offsetY);
-    } else if (m_sequenceMessageType == Uml::sequence_message_found) {
+    } else if (m_sequenceMessageType == Uml::SequenceMessage::Found) {
         drawFound(p, offsetX, offsetY);
     } else {
         uWarning() << "Unknown message type";
@@ -228,14 +228,14 @@ void MessageWidget::drawArrow(QPainter& p, int x, int y, int w,
  */
 void MessageWidget::drawSynchronous(QPainter& p, int offsetX, int offsetY)
 {
-    int x1 = m_pOw[Uml::A]->x();
-    int x2 = m_pOw[Uml::B]->x();
+    int x1 = m_pOw[Uml::RoleType::A]->x();
+    int x2 = m_pOw[Uml::RoleType::B]->x();
     int w = width() - 1;
     int h = height();
 
-    bool messageOverlaps = m_pOw[Uml::A] -> messageOverlap( y(), this );
+    bool messageOverlaps = m_pOw[Uml::RoleType::A]->messageOverlap( y(), this );
 
-    if(m_pOw[Uml::A] == m_pOw[Uml::B]) {
+    if(m_pOw[Uml::RoleType::A] == m_pOw[Uml::RoleType::B]) {
         p.fillRect( offsetX, offsetY, 17, h,  QBrush(Qt::white) );              //box
         p.drawRect(offsetX, offsetY, 17, h);                                    //box
         offsetX += 17;
@@ -287,14 +287,14 @@ void MessageWidget::drawSynchronous(QPainter& p, int offsetX, int offsetY)
  */
 void MessageWidget::drawAsynchronous(QPainter& p, int offsetX, int offsetY)
 {
-    int x1 = m_pOw[Uml::A]->x();
-    int x2 = m_pOw[Uml::B]->x();
+    int x1 = m_pOw[Uml::RoleType::A]->x();
+    int x2 = m_pOw[Uml::RoleType::B]->x();
     int w = width() - 1;
     int h = height() - 1;
-    bool messageOverlapsA = m_pOw[Uml::A] -> messageOverlap( y(), this );
-    //bool messageOverlapsB = m_pOw[Uml::B] -> messageOverlap( y(), this );
+    bool messageOverlapsA = m_pOw[Uml::RoleType::A] -> messageOverlap( y(), this );
+    //bool messageOverlapsB = m_pOw[Uml::RoleType::B] -> messageOverlap( y(), this );
 
-    if(m_pOw[Uml::A] == m_pOw[Uml::B]) {
+    if(m_pOw[Uml::RoleType::A] == m_pOw[Uml::RoleType::B]) {
         if (messageOverlapsA)  {
             offsetX += 7;
             w -= 7;
@@ -310,16 +310,16 @@ void MessageWidget::drawAsynchronous(QPainter& p, int offsetX, int offsetY)
             offsetX -= 7; //reset for drawSelected()
         }
     } else if(x1 < x2) {
-        if (messageOverlapsA)  {
+        if (messageOverlapsA) {
             offsetX += 7;
             w -= 7;
         }
         drawArrow(p, offsetX, offsetY + 4, w, Qt::RightArrow);
-        if (messageOverlapsA)  {
+        if (messageOverlapsA) {
             offsetX -= 7;
         }
     } else      {
-        if (messageOverlapsA)  {
+        if (messageOverlapsA) {
             w -= 7;
         }
         drawArrow(p, offsetX, offsetY + 4, w, Qt::LeftArrow);
@@ -336,25 +336,25 @@ void MessageWidget::drawAsynchronous(QPainter& p, int offsetX, int offsetY)
  */
 void MessageWidget::drawCreation(QPainter& p, int offsetX, int offsetY)
 {
-    int x1 = m_pOw[Uml::A]->x();
-    int x2 = m_pOw[Uml::B]->x();
+    int x1 = m_pOw[Uml::RoleType::A]->x();
+    int x2 = m_pOw[Uml::RoleType::B]->x();
     int w = width() - 1;
     //int h = height() - 1;
-    bool messageOverlapsA = m_pOw[Uml::A] -> messageOverlap( y(), this );
-    //bool messageOverlapsB = m_pOw[Uml::B] -> messageOverlap( y(), this );
+    bool messageOverlapsA = m_pOw[Uml::RoleType::A]->messageOverlap( y(), this );
+    //bool messageOverlapsB = m_pOw[Uml::RoleType::B]->messageOverlap( y(), this );
 
     const int lineY = offsetY + 4;
     if (x1 < x2) {
-        if (messageOverlapsA)  {
+        if (messageOverlapsA) {
             offsetX += 7;
             w -= 7;
         }
         drawArrow(p, offsetX, lineY, w, Qt::RightArrow);
-        if (messageOverlapsA)  {
+        if (messageOverlapsA) {
             offsetX -= 7;
         }
     } else      {
-        if (messageOverlapsA)  {
+        if (messageOverlapsA) {
             w -= 7;
         }
         drawArrow(p, offsetX, lineY, w, Qt::LeftArrow);
@@ -371,16 +371,16 @@ void MessageWidget::drawCreation(QPainter& p, int offsetX, int offsetY)
  */
 void MessageWidget::drawLost(QPainter& p, int offsetX, int offsetY)
 {
-    int x1 = m_pOw[Uml::A]->x();
+    int x1 = m_pOw[Uml::RoleType::A]->x();
     int x2 = xclicked;
-    int w1 = m_pOw[Uml::A]->width() / 2;
+    int w1 = m_pOw[Uml::RoleType::A]->width() / 2;
     x1 += w1;
 
     int w = width() ;
 
     int h = 10;
-    bool messageOverlapsA = m_pOw[Uml::A] -> messageOverlap( y(), this );
-    //bool messageOverlapsB = m_pOw[Uml::B] -> messageOverlap( y(), this );
+    bool messageOverlapsA = m_pOw[Uml::RoleType::A] -> messageOverlap( y(), this );
+    //bool messageOverlapsB = m_pOw[Uml::RoleType::B] -> messageOverlap( y(), this );
 
     if(x1 < x2) {
         if (messageOverlapsA)  {
@@ -412,13 +412,13 @@ void MessageWidget::drawLost(QPainter& p, int offsetX, int offsetY)
  */
 void MessageWidget::drawFound(QPainter& p, int offsetX, int offsetY)
 {
-    int x1 = m_pOw[Uml::A]->x();
+    int x1 = m_pOw[Uml::RoleType::A]->x();
     int x2 = xclicked;
     int w = width() ;
 
     int h = 10;
-    bool messageOverlapsA = m_pOw[Uml::A] -> messageOverlap( y(), this );
-    //bool messageOverlapsB = m_pOw[Uml::B] -> messageOverlap( y(), this );
+    bool messageOverlapsA = m_pOw[Uml::RoleType::A] -> messageOverlap( y(), this );
+    //bool messageOverlapsB = m_pOw[Uml::RoleType::B] -> messageOverlap( y(), this );
 
     if(x1 < x2) {
         if (messageOverlapsA)  {
@@ -459,7 +459,7 @@ void MessageWidget::drawFound(QPainter& p, int offsetX, int offsetY)
  */
 UMLSceneValue MessageWidget::onWidget(const UMLScenePoint& p)
 {
-    if (m_sequenceMessageType != Uml::sequence_message_synchronous) {
+    if (m_sequenceMessageType != Uml::SequenceMessage::Synchronous) {
         return UMLWidget::onWidget(p);
     }
     // Synchronous message:
@@ -502,7 +502,7 @@ void MessageWidget::setTextPosition()
  * Returns the textX arg with constraints applied.
  * Auxiliary to setTextPosition() and constrainTextPos().
  */
-int MessageWidget::constrainX(int textX, int textWidth, Uml::TextRole tr)
+int MessageWidget::constrainX(int textX, int textWidth, Uml::TextRole::Enum tr)
 {
     int result = textX;
     const int minTextX = x() + 5;
@@ -510,10 +510,10 @@ int MessageWidget::constrainX(int textX, int textWidth, Uml::TextRole tr)
         result = minTextX;
     } else {
         ObjectWidget *objectAtRight = NULL;
-        if (m_pOw[Uml::B]->x() > m_pOw[Uml::A]->x())
-            objectAtRight = m_pOw[Uml::B];
+        if (m_pOw[Uml::RoleType::B]->x() > m_pOw[Uml::RoleType::A]->x())
+            objectAtRight = m_pOw[Uml::RoleType::B];
         else
-            objectAtRight = m_pOw[Uml::A];
+            objectAtRight = m_pOw[Uml::RoleType::A];
         const int objRight_seqLineX = objectAtRight->x() + objectAtRight->width() / 2;
         const int maxTextX = objRight_seqLineX - textWidth - 5;
         if (maxTextX <= minTextX)
@@ -532,10 +532,10 @@ int MessageWidget::constrainX(int textX, int textWidth, Uml::TextRole tr)
  * @param textY        candidate Y value (may be modified by the constraint)
  * @param textWidth    width of the text
  * @param textHeight   height of the text
- * @param tr           Uml::TextRole of the text
+ * @param tr           Uml::TextRole::Enum of the text
  */
 void MessageWidget::constrainTextPos(UMLSceneValue &textX, UMLSceneValue &textY, UMLSceneValue textWidth, UMLSceneValue textHeight,
-                                     Uml::TextRole tr)
+                                     Uml::TextRole::Enum tr)
 {
     textX = constrainX(textX, textWidth, tr);
     // Constrain Y.
@@ -594,10 +594,10 @@ void MessageWidget::calculateWidget()
     setY(m_nY);
 }
 
-void MessageWidget::slotWidgetMoved(Uml::IDType id)
+void MessageWidget::slotWidgetMoved(Uml::ID::Type id)
 {
-    const Uml::IDType idA = m_pOw[Uml::A]->localID();
-    const Uml::IDType idB = m_pOw[Uml::B]->localID();
+    const Uml::ID::Type idA = m_pOw[Uml::RoleType::A]->localID();
+    const Uml::ID::Type idB = m_pOw[Uml::RoleType::B]->localID();
     if (idA != id && idB != id) {
         DEBUG(DBG_SRC) << "id=" << ID2STR(id) << ": ignoring for idA=" << ID2STR(idA)
             << ", idB=" << ID2STR(idB);
@@ -624,7 +624,7 @@ void MessageWidget::slotWidgetMoved(Uml::IDType id)
  */
 bool MessageWidget::hasObjectWidget(ObjectWidget * w)
 {
-    if(m_pOw[Uml::A] == w || m_pOw[Uml::B] == w)
+    if(m_pOw[Uml::RoleType::A] == w || m_pOw[Uml::RoleType::B] == w)
         return true;
     else
         return false;
@@ -650,27 +650,27 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
 {
     m_scene->resetPastePoint();
     // UMLWidget::activate(Log);   CHECK: I don't think we need this ?
-    if (m_pOw[Uml::A] == NULL) {
+    if (m_pOw[Uml::RoleType::A] == NULL) {
         UMLWidget *pWA = m_scene->findWidget(m_widgetAId);
         if (pWA == NULL) {
             DEBUG(DBG_SRC) << "role A object " << ID2STR(m_widgetAId) << " not found";
             return false;
         }
-        m_pOw[Uml::A] = dynamic_cast<ObjectWidget*>(pWA);
-        if (m_pOw[Uml::A] == NULL) {
+        m_pOw[Uml::RoleType::A] = dynamic_cast<ObjectWidget*>(pWA);
+        if (m_pOw[Uml::RoleType::A] == NULL) {
             DEBUG(DBG_SRC) << "role A widget " << ID2STR(m_widgetAId)
                 << " is not an ObjectWidget";
             return false;
         }
     }
-    if (m_pOw[Uml::B] == NULL) {
+    if (m_pOw[Uml::RoleType::B] == NULL) {
         UMLWidget *pWB = m_scene->findWidget(m_widgetBId);
         if (pWB == NULL) {
             DEBUG(DBG_SRC) << "role B object " << ID2STR(m_widgetBId) << " not found";
             return false;
         }
-        m_pOw[Uml::B] = dynamic_cast<ObjectWidget*>(pWB);
-        if (m_pOw[Uml::B] == NULL) {
+        m_pOw[Uml::RoleType::B] = dynamic_cast<ObjectWidget*>(pWB);
+        if (m_pOw[Uml::RoleType::B] == NULL) {
             DEBUG(DBG_SRC) << "role B widget " << ID2STR(m_widgetBId)
                 << " is not an ObjectWidget";
             return false;
@@ -678,10 +678,10 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
     }
     updateResizability();
 
-    UMLClassifier *c = dynamic_cast<UMLClassifier*>(m_pOw[Uml::B]->umlObject());
+    UMLClassifier *c = dynamic_cast<UMLClassifier*>(m_pOw[Uml::RoleType::B]->umlObject());
     UMLOperation *op = NULL;
     if (c && !m_CustomOp.isEmpty()) {
-        Uml::IDType opId = STR2ID(m_CustomOp);
+        Uml::ID::Type opId = STR2ID(m_CustomOp);
         op = dynamic_cast<UMLOperation*>( c->findChildObjectById(opId, true) );
         if (op) {
             // If the UMLOperation is set, m_CustomOp isn't used anyway.
@@ -691,8 +691,8 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
     }
 
     if( !m_pFText ) {
-        Uml::TextRole tr = Uml::TextRole::Seq_Message;
-        if (m_pOw[Uml::A] == m_pOw[Uml::B])
+        Uml::TextRole::Enum tr = Uml::TextRole::Seq_Message;
+        if (m_pOw[Uml::RoleType::A] == m_pOw[Uml::RoleType::B])
             tr = Uml::TextRole::Seq_Message_Self;
         m_pFText = new FloatingTextWidget( m_scene, tr, "" );
         m_pFText->setFont(UMLWidget::font());
@@ -705,13 +705,13 @@ bool MessageWidget::activate(IDChangeLog * /*Log = 0*/)
     QString messageText = m_pFText->text();
     m_pFText->setVisible( messageText.length() > 1 );
 
-    connect(m_pOw[Uml::A], SIGNAL(sigWidgetMoved(Uml::IDType)), this, SLOT(slotWidgetMoved(Uml::IDType)));
-    connect(m_pOw[Uml::B], SIGNAL(sigWidgetMoved(Uml::IDType)), this, SLOT(slotWidgetMoved(Uml::IDType)));
+    connect(m_pOw[Uml::RoleType::A], SIGNAL(sigWidgetMoved(Uml::ID::Type)), this, SLOT(slotWidgetMoved(Uml::ID::Type)));
+    connect(m_pOw[Uml::RoleType::B], SIGNAL(sigWidgetMoved(Uml::ID::Type)), this, SLOT(slotWidgetMoved(Uml::ID::Type)));
 
-    connect(this, SIGNAL(sigMessageMoved()), m_pOw[Uml::A], SLOT(slotMessageMoved()) );
-    connect(this, SIGNAL(sigMessageMoved()), m_pOw[Uml::B], SLOT(slotMessageMoved()) );
-    m_pOw[Uml::A] -> messageAdded(this);
-    m_pOw[Uml::B] -> messageAdded(this);
+    connect(this, SIGNAL(sigMessageMoved()), m_pOw[Uml::RoleType::A], SLOT(slotMessageMoved()) );
+    connect(this, SIGNAL(sigMessageMoved()), m_pOw[Uml::RoleType::B], SLOT(slotMessageMoved()) );
+    m_pOw[Uml::RoleType::A] -> messageAdded(this);
+    m_pOw[Uml::RoleType::B] -> messageAdded(this);
     calculateDimensions();
 
     emit sigMessageMoved();
@@ -791,7 +791,7 @@ void MessageWidget::lwSetFont (QFont font)
  */
 UMLClassifier *MessageWidget::operationOwner()
 {
-    UMLObject *pObject = m_pOw[Uml::B]->umlObject();
+    UMLObject *pObject = m_pOw[Uml::RoleType::B]->umlObject();
     if (pObject == NULL)
         return NULL;
     UMLClassifier *c = dynamic_cast<UMLClassifier*>(pObject);
@@ -848,7 +848,7 @@ UMLClassifier * MessageWidget::seqNumAndOp(QString& seqNum, QString& op)
     } else {
         op = m_CustomOp;
     }
-    UMLObject *o = m_pOw[Uml::B]->umlObject();
+    UMLObject *o = m_pOw[Uml::RoleType::B]->umlObject();
     UMLClassifier *c = dynamic_cast<UMLClassifier*>(o);
     return c;
 }
@@ -861,15 +861,15 @@ UMLClassifier * MessageWidget::seqNumAndOp(QString& seqNum, QString& op)
  */
 void MessageWidget::calculateDimensions()
 {
-    if (m_sequenceMessageType == Uml::sequence_message_synchronous) {
+    if (m_sequenceMessageType == Uml::SequenceMessage::Synchronous) {
         calculateDimensionsSynchronous();
-    } else if (m_sequenceMessageType == Uml::sequence_message_asynchronous) {
+    } else if (m_sequenceMessageType == Uml::SequenceMessage::Asynchronous) {
         calculateDimensionsAsynchronous();
-    } else if (m_sequenceMessageType == Uml::sequence_message_creation) {
+    } else if (m_sequenceMessageType == Uml::SequenceMessage::Creation) {
         calculateDimensionsCreation();
-    } else if (m_sequenceMessageType == Uml::sequence_message_lost) {
+    } else if (m_sequenceMessageType == Uml::SequenceMessage::Lost) {
         calculateDimensionsLost();
-    } else if (m_sequenceMessageType == Uml::sequence_message_found) {
+    } else if (m_sequenceMessageType == Uml::SequenceMessage::Found) {
         calculateDimensionsFound();
     } else {
         uWarning() << "Unknown message type";
@@ -886,16 +886,16 @@ void MessageWidget::calculateDimensionsSynchronous()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::A]->x();
-    int x2 = m_pOw[Uml::B]->x();
-    int w1 = m_pOw[Uml::A]->width() / 2;
-    int w2 = m_pOw[Uml::B]->width() / 2;
+    int x1 = m_pOw[Uml::RoleType::A]->x();
+    int x2 = m_pOw[Uml::RoleType::B]->x();
+    int w1 = m_pOw[Uml::RoleType::A]->width() / 2;
+    int w2 = m_pOw[Uml::RoleType::B]->width() / 2;
     x1 += w1;
     x2 += w2;
 
     int widgetWidth = 0;
     int widgetHeight = 0;
-    if( m_pOw[Uml::A] == m_pOw[Uml::B] ) {
+    if( m_pOw[Uml::RoleType::A] == m_pOw[Uml::RoleType::B] ) {
         widgetWidth = 50;
         x = x1 - 2;
     } else if( x1 < x2 ) {
@@ -923,16 +923,16 @@ void MessageWidget::calculateDimensionsAsynchronous()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::A]->x();
-    int x2 = m_pOw[Uml::B]->x();
-    int w1 = m_pOw[Uml::A]->width() / 2;
-    int w2 = m_pOw[Uml::B]->width() / 2;
+    int x1 = m_pOw[Uml::RoleType::A]->x();
+    int x2 = m_pOw[Uml::RoleType::B]->x();
+    int w1 = m_pOw[Uml::RoleType::A]->width() / 2;
+    int w2 = m_pOw[Uml::RoleType::B]->width() / 2;
     x1 += w1;
     x2 += w2;
 
     int widgetWidth = 0;
     int widgetHeight = 8;
-    if( m_pOw[Uml::A] == m_pOw[Uml::B] ) {
+    if( m_pOw[Uml::RoleType::A] == m_pOw[Uml::RoleType::B] ) {
         widgetWidth = 50;
         x = x1;
         if( height() < 20 ) {
@@ -960,10 +960,10 @@ void MessageWidget::calculateDimensionsCreation()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::A]->x();
-    int x2 = m_pOw[Uml::B]->x();
-    int w1 = m_pOw[Uml::A]->width() / 2;
-    int w2 = m_pOw[Uml::B]->width();
+    int x1 = m_pOw[Uml::RoleType::A]->x();
+    int x2 = m_pOw[Uml::RoleType::B]->x();
+    int w1 = m_pOw[Uml::RoleType::A]->width() / 2;
+    int w2 = m_pOw[Uml::RoleType::B]->width();
     x1 += w1;
     if (x1 > x2)
         x2 += w2;
@@ -980,7 +980,7 @@ void MessageWidget::calculateDimensionsCreation()
     x += 1;
     widgetWidth -= 2;
     m_nPosX = x;
-    m_nY = m_pOw[Uml::B]->y() + m_pOw[Uml::B]->height() / 2;
+    m_nY = m_pOw[Uml::RoleType::B]->y() + m_pOw[Uml::RoleType::B]->height() / 2;
     setSize(widgetWidth, widgetHeight);
 }
 
@@ -991,9 +991,9 @@ void MessageWidget::calculateDimensionsLost()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::A]->x();
+    int x1 = m_pOw[Uml::RoleType::A]->x();
     int x2 = xclicked;
-    int w1 = m_pOw[Uml::A]->width() / 2;
+    int w1 = m_pOw[Uml::RoleType::A]->width() / 2;
 
     x1 += w1;
 
@@ -1018,9 +1018,9 @@ void MessageWidget::calculateDimensionsFound()
 {
     int x = 0;
 
-    int x1 = m_pOw[Uml::A]->x();
+    int x1 = m_pOw[Uml::RoleType::A]->x();
     int x2 = xclicked;
-    int w1 = m_pOw[Uml::A]->width() / 2;
+    int w1 = m_pOw[Uml::RoleType::A]->width() / 2;
     x1 += w1;
 
 
@@ -1044,13 +1044,13 @@ void MessageWidget::calculateDimensionsFound()
  */
 void MessageWidget::cleanup()
 {
-    if (m_pOw[Uml::A]) {
-        disconnect(this, SIGNAL(sigMessageMoved()), m_pOw[Uml::A], SLOT(slotMessageMoved()) );
-        m_pOw[Uml::A]->messageRemoved(this);
+    if (m_pOw[Uml::RoleType::A]) {
+        disconnect(this, SIGNAL(sigMessageMoved()), m_pOw[Uml::RoleType::A], SLOT(slotMessageMoved()) );
+        m_pOw[Uml::RoleType::A]->messageRemoved(this);
     }
-    if (m_pOw[Uml::B]) {
-        disconnect(this, SIGNAL(sigMessageMoved()), m_pOw[Uml::B], SLOT(slotMessageMoved()) );
-        m_pOw[Uml::B]->messageRemoved(this);
+    if (m_pOw[Uml::RoleType::B]) {
+        disconnect(this, SIGNAL(sigMessageMoved()), m_pOw[Uml::RoleType::B], SLOT(slotMessageMoved()) );
+        m_pOw[Uml::RoleType::B]->messageRemoved(this);
     }
 
     UMLWidget::cleanup();
@@ -1086,14 +1086,14 @@ void MessageWidget::setSelected(bool _select)
  */
 int MessageWidget::getMinY()
 {
-    if (!m_pOw[Uml::A] || !m_pOw[Uml::B]) {
+    if (!m_pOw[Uml::RoleType::A] || !m_pOw[Uml::RoleType::B]) {
         return 0;
     }
-    if (m_sequenceMessageType == Uml::sequence_message_creation) {
-        return m_pOw[Uml::A]->y() + m_pOw[Uml::A]->height();
+    if (m_sequenceMessageType == Uml::SequenceMessage::Creation) {
+        return m_pOw[Uml::RoleType::A]->y() + m_pOw[Uml::RoleType::A]->height();
     }
-    int heightA = m_pOw[Uml::A]->y() + m_pOw[Uml::A]->height();
-    int heightB = m_pOw[Uml::B]->y() + m_pOw[Uml::B]->height();
+    int heightA = m_pOw[Uml::RoleType::A]->y() + m_pOw[Uml::RoleType::A]->height();
+    int heightB = m_pOw[Uml::RoleType::B]->y() + m_pOw[Uml::RoleType::B]->height();
     int height = heightA;
     if( heightA < heightB ) {
         height = heightB;
@@ -1108,11 +1108,11 @@ int MessageWidget::getMinY()
  */
 int MessageWidget::getMaxY()
 {
-    if( !m_pOw[Uml::A] || !m_pOw[Uml::B] ) {
+    if( !m_pOw[Uml::RoleType::A] || !m_pOw[Uml::RoleType::B] ) {
         return 0;
     }
-    int heightA = (int)((ObjectWidget*)m_pOw[Uml::A])->getEndLineY();
-    int heightB = (int)((ObjectWidget*)m_pOw[Uml::B])->getEndLineY();
+    int heightA = (int)((ObjectWidget*)m_pOw[Uml::RoleType::A])->getEndLineY();
+    int heightB = (int)((ObjectWidget*)m_pOw[Uml::RoleType::B])->getEndLineY();
     int height = heightA;
     if( heightA > heightB ) {
         height = heightB;
@@ -1124,9 +1124,9 @@ int MessageWidget::getMaxY()
  * Sets the related widget on the given side.
  *
  * @param ow     The ObjectWidget we are related to.
- * @param role   The Uml::Role_Type to be set for the ObjectWidget
+ * @param role   The Uml::RoleType::Enum to be set for the ObjectWidget
  */
-void MessageWidget::setObjectWidget(ObjectWidget * ow, Uml::Role_Type role)
+void MessageWidget::setObjectWidget(ObjectWidget * ow, Uml::RoleType::Enum role)
 {
     m_pOw[role] = ow;
     updateResizability();
@@ -1137,7 +1137,7 @@ void MessageWidget::setObjectWidget(ObjectWidget * ow, Uml::Role_Type role)
  *
  * @return  The ObjectWidget we are related to.
  */
-ObjectWidget* MessageWidget::objectWidget(Uml::Role_Type role)
+ObjectWidget* MessageWidget::objectWidget(Uml::RoleType::Enum role)
 {
     return m_pOw[role];
 }
@@ -1150,7 +1150,6 @@ void MessageWidget::setxclicked(int xclick)
     xclicked = xclick;
 }
 
-
 /**
  * Set the yclicked
  */
@@ -1166,8 +1165,8 @@ void MessageWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
 {
     QDomElement messageElement = qDoc.createElement( "messagewidget" );
     UMLWidget::saveToXMI( qDoc, messageElement );
-    messageElement.setAttribute( "widgetaid", ID2STR(m_pOw[Uml::A]->localID()) );
-    messageElement.setAttribute( "widgetbid", ID2STR(m_pOw[Uml::B]->localID()) );
+    messageElement.setAttribute( "widgetaid", ID2STR(m_pOw[Uml::RoleType::A]->localID()) );
+    messageElement.setAttribute( "widgetbid", ID2STR(m_pOw[Uml::RoleType::B]->localID()) );
     UMLOperation *pOperation = operation();
     if (pOperation)
         messageElement.setAttribute( "operation", ID2STR(pOperation->id()) );
@@ -1175,7 +1174,7 @@ void MessageWidget::saveToXMI(QDomDocument & qDoc, QDomElement & qElement)
         messageElement.setAttribute( "operation", m_CustomOp );
     messageElement.setAttribute( "seqnum", m_SequenceNumber );
     messageElement.setAttribute( "sequencemessagetype", m_sequenceMessageType );
-    if (m_sequenceMessageType == Uml::sequence_message_lost || m_sequenceMessageType == Uml::sequence_message_found) {
+    if (m_sequenceMessageType == Uml::SequenceMessage::Lost || m_sequenceMessageType == Uml::SequenceMessage::Found) {
         messageElement.setAttribute( "xclicked", xclicked );
         messageElement.setAttribute( "yclicked", yclicked );
     }
@@ -1203,8 +1202,8 @@ bool MessageWidget::loadFromXMI(QDomElement& qElement)
     m_CustomOp = qElement.attribute( "operation", "" );
     m_SequenceNumber = qElement.attribute( "seqnum", "" );
     QString sequenceMessageType = qElement.attribute( "sequencemessagetype", "1001" );
-    m_sequenceMessageType = (Uml::Sequence_Message_Type)sequenceMessageType.toInt();
-    if (m_sequenceMessageType == Uml::sequence_message_lost || m_sequenceMessageType == Uml::sequence_message_found) {
+    m_sequenceMessageType = Uml::SequenceMessage::fromInt(sequenceMessageType.toInt());
+    if (m_sequenceMessageType == Uml::SequenceMessage::Lost || m_sequenceMessageType == Uml::SequenceMessage::Found) {
         xclicked = qElement.attribute( "xclicked", "-1" ).toInt();
         yclicked = qElement.attribute( "yclicked", "-1" ).toInt();
     }
@@ -1213,7 +1212,7 @@ bool MessageWidget::loadFromXMI(QDomElement& qElement)
     m_widgetBId = STR2ID(widgetbid);
     m_textId = STR2ID(textid);
 
-    Uml::TextRole tr = Uml::TextRole::Seq_Message;
+    Uml::TextRole::Enum tr = Uml::TextRole::Seq_Message;
     if (m_widgetAId == m_widgetBId)
         tr = Uml::TextRole::Seq_Message_Self;
 
