@@ -4,16 +4,13 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2011                                               *
+ *   copyright (C) 2003-2012                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "packagewidget.h"
 
-// qt/kde includes
-#include <QtGui/QPainter>
-
 // app includes
 #include "debug_utils.h"
 #include "package.h"
@@ -22,11 +19,14 @@
 #include "umlview.h"
 #include "umlobject.h"
 
+// qt includes
+#include <QPainter>
+
 /**
  * Constructs a PackageWidget.
  *
- * @param scene              The parent of this PackageWidget.
- * @param o         The UMLObject this will be representing.
+ * @param scene   The parent of this PackageWidget.
+ * @param o       The UMLObject this will be representing.
  */
 PackageWidget::PackageWidget(UMLScene * scene, UMLPackage *o)
   : UMLWidget(scene, WidgetBase::wt_Package, o)
@@ -51,13 +51,13 @@ PackageWidget::~PackageWidget()
 /**
  * Overrides standard method.
  */
-void PackageWidget::paint(QPainter & p, int offsetX, int offsetY)
+void PackageWidget::draw(QPainter & p, int offsetX, int offsetY)
 {
     setPenFromSettings(p);
     if ( UMLWidget::useFillColor() )
         p.setBrush( UMLWidget::fillColor() );
     else
-        p.setBrush( m_scene->view()->viewport()->palette().color(QPalette::Background) );
+        p.setBrush( m_scene->activeView()->viewport()->palette().color(QPalette::Background) );
 
     int w = width();
     int h = height();
@@ -69,7 +69,7 @@ void PackageWidget::paint(QPainter & p, int offsetX, int offsetY)
     const int fontHeight  = fm.lineSpacing();
 
     p.drawRect(offsetX, offsetY, 50, fontHeight);
-    if (m_pObject->stereotype() == "subsystem") {
+    if (m_umlObject->stereotype() == "subsystem") {
         const int fHalf = fontHeight / 2;
         const int symY = offsetY + fHalf;
         const int symX = offsetX + 38;
@@ -84,11 +84,11 @@ void PackageWidget::paint(QPainter & p, int offsetX, int offsetY)
     p.setFont(font);
 
     int lines = 1;
-    if (m_pObject != NULL) {
-        QString stereotype = m_pObject->stereotype();
+    if (m_umlObject != NULL) {
+        QString stereotype = m_umlObject->stereotype();
         if (!stereotype.isEmpty()) {
             p.drawText(offsetX, offsetY + fontHeight + PACKAGE_MARGIN,
-                       w, fontHeight, Qt::AlignCenter, m_pObject->stereotype(true));
+                       w, fontHeight, Qt::AlignCenter, m_umlObject->stereotype(true));
             lines = 2;
         }
     }
@@ -106,7 +106,7 @@ void PackageWidget::paint(QPainter & p, int offsetX, int offsetY)
  */
 UMLSceneSize PackageWidget::minimumSize()
 {
-    if ( !m_pObject ) {
+    if ( !m_umlObject ) {
         return UMLWidget::minimumSize();
     }
 
@@ -115,11 +115,11 @@ UMLSceneSize PackageWidget::minimumSize()
 
     int lines = 1;
 
-    int width = fm.width( m_pObject->name() );
+    int width = fm.width( m_umlObject->name() );
 
     int tempWidth = 0;
-    if (!m_pObject->stereotype().isEmpty()) {
-        tempWidth = fm.width(m_pObject->stereotype(true));
+    if (!m_umlObject->stereotype().isEmpty()) {
+        tempWidth = fm.width(m_umlObject->stereotype(true));
         lines = 2;
     }
     if (tempWidth > width)
