@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -33,7 +33,7 @@ class PreconditionWidget : public UMLWidget
 {
     Q_OBJECT
 public:
-    PreconditionWidget(UMLScene* scene, ObjectWidget* a, Uml::IDType id = Uml::id_None);
+    PreconditionWidget(UMLScene* scene, ObjectWidget* a, Uml::ID::Type id = Uml::ID::None);
     virtual ~PreconditionWidget();
 
     int minY() const;
@@ -48,7 +48,7 @@ public:
 
 public slots:
     void slotMenuSelection(QAction* action);
-    void slotWidgetMoved(Uml::IDType id);
+    void slotWidgetMoved(Uml::ID::Type id);
 
 protected:
     UMLSceneSize minimumSize();
