@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -28,7 +28,7 @@
  * @param scene   The parent of the widget.
  * @param id      The ID to assign (-1 will prompt a new ID.)
  */
-RegionWidget::RegionWidget(UMLScene* scene, Uml::IDType id)
+RegionWidget::RegionWidget(UMLScene* scene, Uml::ID::Type id)
   : UMLWidget(scene, WidgetBase::wt_Region, id)
 {
 }
