@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2012                                               *
+ *   copyright (C) 2002-2013                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
 ***************************************************************************/
 
@@ -20,7 +20,7 @@ class RegionWidget: public UMLWidget
 {
     Q_OBJECT
 public:
-    explicit RegionWidget(UMLScene* scene, Uml::IDType id = Uml::id_None);
+    explicit RegionWidget(UMLScene* scene, Uml::ID::Type id = Uml::ID::None);
     virtual ~RegionWidget();
 
     void draw(QPainter& p, int offsetX, int offsetY);
